@@ -47,9 +47,9 @@ class CGSmartImage extends CGExtensions
   function LazyLoadFrontend() { return FALSE; }
   function GetName() { return get_class($this); }
   function GetFriendlyName() { return $this->Lang('friendlyname');  }
-  function GetVersion() { return '1.13'; }
+  function GetVersion() { return '1.14'; }
   function MinimumCMSVersion() { return '1.11.8'; }
-  function GetDependencies() { return array('CGExtensions'=>'1.37.2');   }
+  function GetDependencies() { return array('CGExtensions'=>'1.37.3');   }
   function GetAuthor() { return 'calguy1000'; }
   function GetAuthorEmail() { return 'calguy1000@gmail.com'; }
   function IsPluginModule() { return TRUE; }
@@ -82,6 +82,8 @@ class CGSmartImage extends CGExtensions
     $this->SetParameterType('noremote',CLEAN_INT);
     $this->SetParameterType('src',CLEAN_STRING);
     $this->SetParameterType('overwrite',CLEAN_INT);
+    $this->SetParameterType('force_ext',CLEAN_INT);
+    $this->SetParameterType('force_type',CLEAN_STRING);
 
     // params for the output tag (if outputting an img tag)
     $this->SetParameterType('id',CLEAN_STRING);
@@ -120,6 +122,8 @@ class CGSmartImage extends CGExtensions
     $this->CreateParameter('noresponsive','',$this->Lang('param_noresponsive'));
     $this->CreateParameter('nobreakpoints','',$this->Lang('param_nobreakpoints'));
     $this->CreateParameter('noremote','',$this->Lang('param_noremote'));
+    $this->CreateParameter('force_type','',$this->Lang('param_forcetype'));
+    $this->CreateParameter('force_ext','',$this->Lang('param_forceext'));
     $this->CreateParameter('src','',$this->Lang('param_src'),false);
     $this->CreateParameter('overwrite','',$this->Lang('param_overwrite'));
     $this->CreateParameter('id','',$this->Lang('param_id'));
@@ -288,4 +292,4 @@ class CGSmartImage extends CGExtensions
 
 } // end of class
 
-?>
\ No newline at end of file
+?>
