@@ -40,8 +40,9 @@ $outp = cgsi_utils::process_image($params);
 $silent = $this->GetPreference('silent',0);
 if( isset($params['silent']) ) $silent = (int)$params['silent'];
 
-if( isset($outp['error']) && $outp['error'] != '' && !$silent ) {
-  trigger_error($outp['error']);
+if( isset($outp['error']) && $outp['error'] != '' ) {
+  if( !$silent ) trigger_error($outp['error']);
+  audit('',$this->GetName(),$outp['error']);
   return;
 }
 
