@@ -46,6 +46,7 @@ $lang['info_aliases'] = 'Aliaes can be used via the alias1 through alias5 option
 $lang['info_check_memory'] = 'If enabled, the system will attempt to estimate memory needed for an image transformation, and will fail if insufficient available memory is detected';
 $lang['info_croptofit_default_loc'] = 'Specify the default location from which to &quot;crop to fit&quot; this will effect all crop to fit operations unless the location parameter on the filter_croptofit attribute overrides it.  Default location is &quot;center&quot;';
 $lang['info_responsive'] = 'If enabled, CGSmartImage will attempt to detect the maximum resolution of the requesting device and automatically rescale the image so that under no circumstances can the output image be too large for the display.  This assists in performance when developing mobile websites.';
+$lang['info_force_extension'] = 'If enabled, CGSmartImage will force all generated images to have a file extension. <strong>Note:</strong> Though all efforts are made to ensure correctness, the file extension generated may not accurately represent the actual image type, depending upon the filters used and the parameters to those filters.';
 $lang['info_responsive_breakpoints'] = '<strong>Experimental:</strong> If specified, and a mobile device is detected the breakpoints will be used to determine the maximum largest edge for the resulting image.  Specify a list of comma separated increasing integers <em>(i.e: 200,400,600,800)</em>. The device capabilties will be used to find the closest matching breakpoint value.  The image will be resized so that its largest edge is at that value without upscaling.  Aspect ratio will be maintained.';
 $lang['image_url_hascachedir'] = 'Does the URL above acount for the cache path? ie. (uploads/_CGSmartImage)';
 $lang['image_url_prefix'] = 'Image Url Prefix';
@@ -110,6 +111,8 @@ $lang['param_filter_sharpen'] = '(integer) Specify an adjustment (between -10 an
 $lang['param_filter_transparent'] = '(color[,alpha]) Converts a jpeg image to transparent PNG by converting all of the pixels of the specified color to the transparent color.  Optionally, an alpha value between 0 and 127 can be specified to indicate some alpha level blending';
 $lang['param_filter_untransparent'] = '(color[,percent]) Converts a transparent png image to a jpeg image by copying a transparent/alpha blended png overtop of an image of the appropriate color.';
 $lang['param_filter_watermark'] = '(anything), Specify that the watermark (as specified in the CGExtensions admin panel) should be applied to the image';
+$lang['param_forceext'] = '(integer) Enable (or disabled) the forcing of all generated image files to have file extensions.  Depending upon the source image, and the filters and parameters used, the generated extension may not accurately represent the actual contents of the file';
+$lang['param_forcetype'] = '(string) Force the output image to be saved in the specified image type, independent of the source image, filters, and parameters.  Valid values are: jpeg,png,gif. Note: Due to the capabilities of some image formats, surprising effects can occur.  Particularly, forcing a transparent PNG to save in JPEG format will result in all transparency being lost.';
 $lang['param_height'] = 'Used when creating an img tag, specify the value for the height attribute.  Note, if this is not specified a value will be automatically calculated for this attribute so that most generated img tags will validate.  You can override this auto calculation with the &quot;noauto&quot; parameter.  This parameter will also be used in conjunction with the &quot;width&quot; parameter to perform a final resizing or croptofit filter (unless the &quot;noautoscale&quot; parameter is also supplied)';
 $lang['param_id'] = 'Used when creating an img tag, allows specifying an id attribute to include on the tag.  i.e: id="sometag"';
 $lang['param_max_height'] = 'This parameter allows specifying a maximum height for the converted images.';
@@ -147,6 +150,7 @@ $lang['prompt_croptofit_default_loc'] = 'Default location from which to &quot;cr
 $lang['prompt_embed_sizelimit'] = 'Based on image size';
 $lang['prompt_embed_smartlimited'] = 'Smart mode but limit image size';
 $lang['prompt_embed_type'] = 'Based on image type';
+$lang['prompt_force_extension'] = 'Force all output files to have a file extension';
 $lang['prompt_loc_bottomleft'] = 'Bottom Left (bl)';
 $lang['prompt_loc_bottomcenter'] = 'Bottom Center (bc)';
 $lang['prompt_loc_bottomright'] = 'Bottom Right (br)';
