@@ -38,33 +38,25 @@
 class CGImageBase implements ArrayAccess
 {
   private $_transparent;
+  private $_savealpha; // indicates that the image should be saved with alpha channels
   private $_rsrc;
   private $_srcname;
   private $_dirty;
   private $_info;
-  private static $_keys = array('dirty','rsrc','width','height','type','filename','name','transparent');
+  private static $_keys = array('dirty','rsrc','width','height','type','filename','name','transparent','savealpha');
 
   private function create_new_rsrc($mimetype,$width,$height)
   {
     switch( $mimetype ) {
     case 'image/jpeg':
       $_rsrc = imagecreatetruecolor($width,$height);
-      //imageinterlace($_rsrc, false);
       return $_rsrc;
 
     case 'image/png':
       // from supersizer
       $_rsrc = imagecreatetruecolor($width, $height);  
-      $black = imagecolorallocatealpha($_rsrc,0,0,0,127);
-      imagecolortransparent($_rsrc, $black);   
-      // Turn off transparency blending (temporarily)
-      imagealphablending($_rsrc, false);
-      // Create a new transparent color for image
       $color = imagecolorallocatealpha($_rsrc, 0, 0, 0, 127);
-      // Completely fill the background of the new image with allocated color.
-      imagefill($_rsrc, 0, 0, $color);
-      // Restore transparency blending
-      imagesavealpha($_rsrc, true);
+      imagecolortransparent($_rsrc,$color);
       $this->_transparent = $color;
       return $_rsrc;
 
@@ -74,7 +66,7 @@ class CGImageBase implements ArrayAccess
       imagealphablending($_rsrc, false);
       imagesavealpha($_rsrc,true);
       $transparent = imagecolorallocatealpha($_rsrc, 255, 255, 255, 127);
-      imagefilledrectangle($_rsrc, 0, 0, $width, $height, $transparent);
+      imagefilledrectangle($_rsrc, 0, 0, $width, $heightd, $transparent);
       imagecolortransparent($_rsrc, $transparent);
       return $_rsrc;
 
@@ -88,6 +80,8 @@ class CGImageBase implements ArrayAccess
   {
     if( is_object($input) && $input instanceof CGImageBase  ) {
       // copy constructor
+      $this->_savealpha = $input->_savealpha;
+      $this->_transparent = $input->_transparent;
       $this->_rsrc = $input->_rsrc;
       $this->_srcname = $input->_srcname;
       $this->_info = $input->_info;
@@ -99,12 +93,14 @@ class CGImageBase implements ArrayAccess
 	$this->_rsrc = imagecreatefromstring($data);
 	$this->_srcname = $input;
 	$this->_info = getimagesize($input);
+	$tmp = imagecolortransparent($this->_rsrc);
+	if( $tmp != -1 ) $this->_transparent = $tmp;
 	$this->_info[2] = image_type_to_mime_type($this->_info[2]);
 	return;
       }
       throw new Exception('Problem creating new CGImageBase object from '.$input);
     }
-    else if( is_array($input) && count($input) == 3 ) {
+    else if( is_array($input) && count($input) >= 3 ) {
       $this->_rsrc = $this->create_new_rsrc($input[0],$input[1],$input[2]);
       $this->_info = array($input[1],$input[2],$input[0]);
       $this->_dirty = 1;
@@ -160,6 +156,9 @@ class CGImageBase implements ArrayAccess
       return $this->_transparent;
       break;
 
+    case 'savealpha':
+      return $this->_savealpha;
+
     case 'filename':
     case 'name':
       return $this->_srcname;
@@ -196,6 +195,10 @@ class CGImageBase implements ArrayAccess
       $this->_info[2] = $v;
       break;
 
+    case 'savealpha':
+      $this->_salvealpha = (bool)$v;
+      break;
+
     case 'filename':
     case 'name':
       $this->_srcname = $v;
@@ -216,13 +219,26 @@ class CGImageBase implements ArrayAccess
       break;
 
     case 'image/png':
+//       if( $this->_savealpha ) {
+// 	imagesavealpha($this['rsrc'],TRUE);
+//       }
+//       else {
+// 	imagesavealpha($this['rsrc'],FALSE);
+//       }
       $quality = ceil((100.0 - (float)$quality)/100.0*10.0);
       $res = imagepng($this['rsrc'],$filename,$quality);
       break;
 
     case 'image/gif':
+      if( $this->_savealpha ) {
+	imagesavealpha($this['rsrc'],TRUE);
+      }
+      else {
+	imagesavealpha($this['rsrc'],FALSE);
+      }
       $res = imagegif($this['rsrc'],$filename);
       break;
+
     default:
       throw new Exception('Cannot save image of type '.$this['type']);
     }
@@ -231,6 +247,17 @@ class CGImageBase implements ArrayAccess
     throw new Exception('Error saving image of type '.$this['type'].' to '.$filename);
   }
 
+  public function supports_transparency()
+  {
+    switch( $this['type'] ) {
+    case 'image/gif':
+    case 'image/png':
+      return TRUE;
+
+    default:
+      return FALSE;
+    }
+  }
 } // class CGImageBase
 
 // $img1 = new CGImage($somefilename);
