@@ -189,7 +189,7 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
     }
 
     // create destination image at the desired thumb size.
-    $_dest = new CGImageBase(array($src['type'],$this->_dest_w,$this->_dest_h));
+    $_dest = new CGImageBase(array('image/png',$this->_dest_w,$this->_dest_h));
 
     // set this transparent color into into the dest image.
     $transparent2 = imagecolorallocatealpha($_dest['rsrc'], $tr, $tg, $tb, $ta);
