@@ -39,7 +39,7 @@ class CGImage_Resize_Filter extends CGImageFilterBase
 {
   private $_width;         // dest width
   private $_height;        // dest height
-  private $_edge = 0;	   //edge size
+  private $_edge = 0;	   // edge size
   private $_percent = 0;   // scale to percent
   private $_resample = 1;  // resample, vs resize.
   private $_upscale = 1;   // allow upscale by default.
@@ -58,6 +58,7 @@ class CGImage_Resize_Filter extends CGImageFilterBase
       }
       if( isset($input['resample']) ) $this->_resample = (int)$input['resample'];
       if( isset($input['upscale']) ) $this->_upscale = (int)$input['upscale'];
+      if( isset($input['edge']) ) $this->_edge = (int)$input['edge'];
     }
     else if( is_array($input) && count($input) >= 2 ) {
       $idx = 2;
@@ -94,12 +95,8 @@ class CGImage_Resize_Filter extends CGImageFilterBase
   private function _transform(CGImageBase $src,$new_w,$new_h)
   {
     if( !$this->_upscale ) {
-      if( $new_w > $src['width']  || $new_h > $src['height'] ) {
-	// upscaling
-	return $src;
-      }
+      if( $new_w > $src['width'] || $new_h > $src['height'] ) return $src; // upscaling
     }
-
     $_dest = new CGImageBase(array($src['type'],$new_w,$new_h));
 
     $res = '';
@@ -109,8 +106,8 @@ class CGImage_Resize_Filter extends CGImageFilterBase
     else {
       $res = imagecopyresized($_dest['rsrc'],$src['rsrc'],0,0,0,0,$new_w,$new_h,$src['width'],$src['height']);
     }
-    if( !$res ) throw new Exception('Image Transform Failed');
 
+    if( !$res ) throw new Exception('Image Transform Failed');
     return $_dest;
   }
 
@@ -142,13 +139,12 @@ class CGImage_Resize_Filter extends CGImageFilterBase
   protected function _transform_edge(CGImageBase $src)
   {
     //find the longest edge of image and resize based on it
-    if($src['width'] > $src['height']){
+    if($src['width'] > $src['height']) {
         $new_w = $this->_edge;
 	$new_w = cgsi_utils::trim_to_device('width',$new_w);
         $new_h = (int)($this->_edge * $src['height'] / $src['width']);
         return $this->_transform($src,$new_w,$new_h);
-
-    }else{
+    } else {
         $new_h = $this->_edge;
 	$new_h = cgsi_utils::trim_to_device('height',$new_h);
         $new_w = (int)($this->_edge * $src['width'] / $src['height']);
@@ -159,31 +155,30 @@ class CGImage_Resize_Filter extends CGImageFilterBase
   protected function _transform_custom(CGImageBase $src)
   {
     // this does not preserve aspect ratio.
-    $new_w = $this->_width;
-    $new_h = $this->_height;
-    return $this->_transform($src,$new_w,$new_h);
+    return $this->_transform($src,$this->_width,$this->_height);
   }
 
 
   public function transform(CGImageBase $img)
   {
-    if( $this->_percent > 0 ) {
-      // percentage resize.
-      return $this->_transform_percentage($img);
-    }
-    if($this->_edge > 0 && ($img['width'] > $this->_edge || $img['height'] > $this->_edge)){
+    if( $this->_percent > 0 ) return $this->_transform_percentage($img); // percentage resize.
+    if( $this->_edge > 0 && ($img['width'] > $this->_edge || $img['height'] > $this->_edge) ) {
       //resize by longest edge
       return $this->_transform_edge($img);
     }
     if( $this->_width > 0 && $this->_height == 0 && $img['width'] > $this->_width ) {
       return $this->_transform_width($img);
     }
-    if( $this->_width == 0 && $this->_height > 0 && $img['height'] > $this->_height ) {
-      return $this->_transform_height($img);
-    }
-    if( $this->_width > 0 && $this->_height > 0 && $img['width'] > $this->_width && $img['height'] > $this->_height ) {
+    if( $this->_width == 0 && $this->_height > 0 && $img['height'] > $this->_height ) return $this->_transform_height($img);
+    if( $this->_width > 0 && $this->_height > 0 ) {
+      if( $img['width'] == $this->_width && $img['height'] == $this->_height ) {
+	// nothing to do... but trick the image to be dirty.
+	$img['height'] = $img['height'];
+	return $img;
+      }
       return $this->_transform_custom($img);
     }
+
     // nothing to do.... but trick the image to be dirty.
     $img['height'] = $img['height'];
     return $img;
