@@ -71,9 +71,10 @@ class CGImage_Resizetofit_Filter extends CGImageFilterBase
 
     $this->_dest_w = cgsi_utils::trim_to_device('width',$this->_dest_w);
     $this->_dest_h = cgsi_utils::trim_to_device('height',$this->_dest_h);
+    $this->_alpha = max(0,min(127,$this->_alpha));
 
     // todo: convert color name into rgb.
-    if( $this->_dest_h <= 0 || $this->_dest_w <= 0 || $this->_alpha < 0 || $this->_alpha > 127 ) {
+    if( $this->_dest_h <= 0 || $this->_dest_w <= 0 ) {
       throw new Exception('Invalid values specified for Croptofit filter constructor');
     }
   }
@@ -81,25 +82,40 @@ class CGImage_Resizetofit_Filter extends CGImageFilterBase
   public function transform(CGImageBase $src)
   {
     // quick optimization (nothing to do)
-    if( $this->_dest_w == $src['width'] && $this->_dest_h == $src['height'] ) return $src;
+    //if( $this->_dest_w == $src['width'] && $this->_dest_h == $src['height'] ) return $src;
+
+    $type = $src['type'];
+    if( $this->_alpha == 127 ) $this->_color = 'transparent';
+    if( $src->supports_transparency() && !$this->_color ) $this->_color = 'transparent';
+    if( $this->_color == 'transparent' || $this->_alpha > 0 ) $type = 'image/png';
+    if( $this->_color == 'transparent' ) $this->_alpha = 127;
 
     // create our destination image.
-    $_dest = new CGImageBase(array($src['type'],$this->_dest_w,$this->_dest_h));
-    imagealphablending($_dest['rsrc'], TRUE);
+    $_dest = new CGImageBase(array($type,$this->_dest_w,$this->_dest_h));
 
     // fill our image with a color (or transparent)
     $color = null;
-    if( $_dest['transparent'] ) {
-      if( !$this->_color || $this->_color == 'transparent' ) $color = $_dest['transparent'];
-    }
-    if( $color == null ) {
-      $_r = $_g = $_b = 0;
-      if( $this->_color && $this->_color != 'transparent' ) {
+    if( $this->_color ) {
+      if( $this->_color == 'transparent' ) {
+	// need to get a transparent color from someplace
+	$color = $_dest['transparent'];
+      }
+      else {
+	$_r = $_g = $_b = 255;
 	list($_r,$_g,$_b) = cgsi_utils::color_to_rgb($this->_color);
+	$color = imagecolorallocatealpha($_dest['rsrc'], $_r, $_g, $_b, $this->_alpha);
       }
-      $color = imagecolorallocatealpha($_dest['rsrc'], $_r, $_g, $_b, $this->_alpha);
     }
     
+    if( $this->_alpha > 0 && $this->_alpha < 127) {
+      $_dest['savealpha'] = TRUE;
+      imagealphablending($_dest['rsrc'],TRUE);
+      imagesavealpha($_dest['rsrc'],TRUE);
+    } if( $this->_color == 'transparent' ) {
+      imagecolortransparent($_dest['rsrc'],$color);
+      imagealphablending($_dest['rsrc'],FALSE);
+    }
+
     imagefill($_dest['rsrc'], 0, 0, $color);
 
     if( ($this->_dest_w / $this->_dest_h) > ($src['width']/$src['height']) ) {
