@@ -52,25 +52,39 @@ class CGImage_Rotate_Filter extends CGImageFilterBase
    * @var integer
    */
   private $_angle = 0;
+  private $_color;
+  private $_alpha = 0;
 
   public function __construct(/* variable arguments */)
   {
     $args = func_get_args();
     if( is_array($args[0]) && count($args) == 1) $args = $args[0];
-    if( count($args) != 1 ) throw new Exception('Invalid arguments specified for '.get_class($this));
-    $this->_angle = (int)$args[0] % 360;
+    if( count($args) >= 1 ) $this->_angle = (int)$args[0] % 360;
+    if( count($args) >= 2 ) $this->_color = $args[1];
+    if( count($args) >= 3 ) $this->_alpha = (int)$args[2];
+
+    $this->_alpha = max(0,min(127,$this->_alpha));
   }
 
   public function transform(CGImageBase $src)
   {
-    $angle = $this->_angle % 360;
-    if( $angle == 0 ) return $src; // nothing to do.
-
-    $_dest = new CGImageBase($src);
+    if( $this->_angle == 0 ) return $src; // nothing to do.
+    $type = $src['type'];
+    if( $this->_alpha != 0 ) $type = 'image/png';
+    if( $this->_alpha == 127 ) $this->_color = 'transparent';
+    if( $this->_color == 'transparent' ) $type = 'image/png';
 
     if( !function_exists('imagerotate') ) throw new Exception('imagerotate function not found');
 
-    $tcolor = imagecolorat($src['rsrc'],0,$src['height']-1);
+    $_dest = new CGImageBase(array($type,$src['width'],$src['height']));
+
+    if( !$this->_color || $this->_color == 'transparent' ) {
+      $tcolor = cgsi_utils::get_transparent_color($src);
+    }
+    else {
+      list($_r,$_g,$_b) = cgsi_utils::color_to_rgb($this->_color);
+      $tcolor = imagecolorallocatealpha($_dest['rsrc'],$_r,$_g,$_b,$this->_alpha);
+    }
     $res = imagerotate($src['rsrc'],$this->_angle * -1,$tcolor);
     if( $res === FALSE ) throw new Exception('Error applying filter '.IMG_FILTER_COLORIZE);
 
