@@ -38,28 +38,20 @@
 class CGImage_Roundedcorners_Filter extends CGImageFilterBase
 {
   private $_radius;
+  private $_color;
 
   public function __construct($input)
   {
-    if( cge_array::is_hash($input) )
-      {
-	if( isset($input['radius']) )
-	  {
-	    $this->_radius = (int)$input['radius'];
-	  }
-      }
-    else if( is_array($input) )
-      {
-	if( count($input) == 1 )
-	  {
-	    $this->_radius = (int)$input[0];
-	  }
-      }
+    if( cge_array::is_hash($input) ) {
+      if( isset($input['radius']) ) $this->_radius = (int)$input['radius'];
+      if( isset($input['color']) ) $this->_color = $input['color'];
+    }
+    else if( is_array($input) ) {
+      if( count($input) >= 1 ) $this->_radius = (int)$input[0];
+      if( count($input) >= 2 ) $this->_color  = $input[1];
+    }
 
-    if( $this->_radius <= 1 )
-      {
-	throw new Exception('Invalid values specified for Roundedcorners filter constructor');
-      }
+    if( $this->_radius <= 1 ) throw new Exception('Invalid values specified for Roundedcorners filter constructor');
   }
 
 
@@ -68,42 +60,55 @@ class CGImage_Roundedcorners_Filter extends CGImageFilterBase
     $width = $src['width'];
     $height = $src['height'];
     $radius = $this->_radius;
+    $type = $src['type'];
+    $color = null;
+    $r = $g = $b = 255;
 
-    // create the new image 
-    $_dest = new CGImageBase(array($src['type'],$src['width'],$src['height']));
-    //imagealphablending($_dest['rsrc'],TRUE);
-    imagecopy($_dest['rsrc'],$src['rsrc'],0,0,0,0,$src['width'],$src['height']);
-    //imagesavealpha($_dest['rsrc'],true);
+    if( $src->supports_transparency() && !$this->_color ) $this->_color = 'transparent';
+    if( $this->_color == 'transparent' ) $type = 'image/png';
 
-    // find an unsed rgb triplet.
-    $found = false; 
-    while($found == false) { 
-      
-      $r = rand(0, 255); 
-      $g = rand(0, 255); 
-      $b = rand(0, 255); 
-      
-      if(imagecolorexact($src['rsrc'], $r, $g, $b) != (-1)) {         
-        $colorcode = imagecolorallocatealpha($_dest['rsrc'], $r, $g, $b, 127); 
-	imagecolortransparent($_dest['rsrc'],$colorcode);
-        $found = true;         
+    $_dest = new CGImageBase(array($type,$width,$height));
+    imagecopy($_dest['rsrc'],$src['rsrc'],0,0,0,0,$width,$height);
+
+    if( $this->_color ) {
+      if( $this->_color == 'transparent' ) {
+	// get the dest imagages transparent color.
+	$color = $_dest['transparent'];
+	if( !$color ) list($r,$g,$b) = cgsi_utils::find_unused_color($_dest);
+      }
+      else {
+	// use the specified rgb.
+	list($r,$g,$b) = cgsi_utils::color_to_rgb($this->_color);
       }
     }
 
-    //    include_once(dirname(__FILE__).'/imageSmoothArc_optimized.php');
+    if( !$color ) {
+      if( $this->_color == 'transparent' ) {
+	$color = imagecolorallocatealpha($_dest['rsrc'],$r,$g,$b,127);
+      }
+      else {
+	$color = imagecolorallocate($_dest['rsrc'],$r,$g,$b);
+      }
+    }
+
+    if( $this->_color == 'transparent' ) {
+      $_dest['transparent'] = $color;
+      imagecolortransparent($_dest['rsrc'],$color);
+      imagealphablending($_dest['rsrc'],FALSE);
+    }
 
     // round the corners.
-    imagearc($_dest['rsrc'],$radius-1,$radius-1,$radius*2,$radius*2, 180, 270, $colorcode);
-    imagefilltoborder($_dest['rsrc'],0,0,$colorcode,$colorcode);
+    imagearc($_dest['rsrc'],$radius-1,$radius-1,$radius*2,$radius*2, 180, 270, $color);
+    imagefilltoborder($_dest['rsrc'],0,0,$color,$color);
     
-    imagearc($_dest['rsrc'], $width-$radius, $radius-1, $radius*2, $radius*2, 270, 0, $colorcode); 
-    imagefilltoborder($_dest['rsrc'], $width-1, 0, $colorcode, $colorcode);
+    imagearc($_dest['rsrc'], $width-$radius, $radius-1, $radius*2, $radius*2, 270, 0, $color); 
+    imagefilltoborder($_dest['rsrc'], $width-1, 0, $color, $color);
 
-    imagearc($_dest['rsrc'], $radius-1, $height-$radius, $radius*2, $radius*2, 90, 180, $colorcode); 
-    imagefilltoborder($_dest['rsrc'], 0, $height-1, $colorcode, $colorcode);
+    imagearc($_dest['rsrc'], $radius-1, $height-$radius, $radius*2, $radius*2, 90, 180, $color); 
+    imagefilltoborder($_dest['rsrc'], 0, $height-1, $color, $color);
 
-    imagearc($_dest['rsrc'], $width-$radius, $height-$radius, $radius*2, $radius*2, 0, 90, $colorcode); 
-    imagefilltoborder($_dest['rsrc'], $width-1, $height-1, $colorcode, $colorcode);
+    imagearc($_dest['rsrc'], $width-$radius, $height-$radius, $radius*2, $radius*2, 0, 90, $color); 
+    imagefilltoborder($_dest['rsrc'], $width-1, $height-1, $color, $color);
 
     return $_dest;
   }
