@@ -40,6 +40,57 @@ class cgsi_utils
   protected function __construct() {}
   static private $_device_data;
 
+  /**
+   * Given a fairly loose image type identifier (either an extension, or a mime type that could be somewhat mis-spelled
+   * attempt to return a reasonable mime type
+   */
+  private static function parse_type($str,$dflt = 'image/png')
+  {
+    $str = strtolower($str);
+    while( startswith($str,'.') ) $str = substr($str,1);
+
+    switch( $str ) {
+    case 'image/jpeg':
+    case 'image/png':
+    case 'image/gif':
+    case 'image/bmp':
+    case 'image/webp':
+      return $str;
+    case 'image/x-windows-bmp':
+    case 'image/x-ms-bmp':
+      return 'image/bmp';
+    case 'image/jpg':
+    case 'jpeg':
+    case 'jpg':
+      return 'image/jpeg';
+    case 'png':
+      return 'image/png';
+    case 'gif':
+      return 'image/gif';
+    case 'bmp':
+      return 'image/bmp';
+    case 'webp':
+      return 'image/webp';
+    default:
+      return $dflt;
+    }
+  }
+
+  /**
+   * Given a mime type for or known image formats, return an extension
+   */
+  private static function get_extension($mime_type)
+  {
+    $map = array('image/jpeg'=>'.jpg',
+		 'image/png'=>'.png',
+		 'impage/bmp'=>'.bmp',
+		 'image/gif'=>'.gif');
+    if( isset($map[$mime_type]) ) return $map[$mime_type];
+  }
+
+  /**
+   * Return the options for a particular alias 
+   */
   private static function _get_alias_options($name)
   {
     static $aliases;
@@ -212,6 +263,8 @@ class cgsi_utils
     $opp['src'] = '';
     $opp['quality'] = 75;
     $opp['filters'] = array();
+    $opp['force_type'] = '';
+    $opp['force_ext'] = $mod->GetPreference('force_extension',0);
     $srcimgsize = ''; // src image size
     $lastfilter = null;
 
@@ -305,6 +358,7 @@ class cgsi_utils
 	  break;
 
 	case 'src':
+	case 'force_type':
 	  $opp[$key] = trim($value);
 	  break;
 
@@ -323,6 +377,7 @@ class cgsi_utils
 	case 'noauto':
 	case 'norotate':
 	case 'notimecheck':
+	case 'force_ext':
 	  $opp[$key] = cge_utils::to_bool($value);
 	  break;
 	}
@@ -388,15 +443,15 @@ class cgsi_utils
       }
 
       // get the source image size
-      $tmp = getimagesize($srcfile);
-      if( !is_array($tmp) || count($tmp) < 2 ) {
+      $srcinfo = getimagesize($srcfile);
+      if( !is_array($srcinfo) || count($srcinfo) < 2 ) {
 	throw new Exception($mod->Lang('error_srcnotfound',$opp['src']));
       }
       else {
-	$srcimgsize = array('width'=>$tmp[0],'height'=>$tmp[1]);
-	$memory_needed = round( $tmp[0] * $tmp[1] 
-				* (isset($tmp['bits'])?$tmp['bits']:8) 
-				* (isset($tmp['channels'])?$tmp['channels']:3) / 8 + 65535 );
+	$srcimgsize = array('width'=>$srcinfo[0],'height'=>$srcinfo[1]);
+	$memory_needed = round( $srcinfo[0] * $srcinfo[1] 
+				* (isset($srcinfo['bits'])?$srcinfo['bits']:8) 
+				* (isset($srcinfo['channels'])?$srcinfo['channels']:3) / 8 + 65535 );
 	if( $mod->GetPreference('checkmemory',1) && !cge_utils::have_enough_memory($memory_needed) ) {
 	  throw new Exception($mod->Lang('error_insufficientmemory')+': '.(int)($memory_needed/1024)+'k');
 	}
@@ -535,6 +590,12 @@ class cgsi_utils
 	}
       }
 
+      // if we are forcing a type and that type is not the same as our current type.
+      if( $opp['force_type'] ) {
+	$tmp_a = self::parse_type($opp['force_type']);
+	if( $tmp_a != $srcinfo['mime'] ) $want_transform = 1;
+      }
+
       // if we have max width and/or height... add a filter at the end
       // to make sure that our output never exceeds those max values.
       if( ($opp['max_width'] > 0 || $opp['max_height'] > 0) && $opp['noautoscale'] == 0 ) {
@@ -603,6 +664,8 @@ class cgsi_utils
 	$ext = strrchr($tmp,'.');
 	$t2 = md5(serialize($opp));
 	$destname = 'img-'.$t2;
+	$t3 = self::parse_type(($opp['force_type'])?$opp['force_type']:$srcinfo['mime']);
+	if( $opp['force_ext'] ) $destname .= self::get_extension($t3);
 
 	$cache_path = $mod->GetPreference('cache_path', cms_join_path('uploads', '_'.$mod->GetName()));
 	$destdir = cms_join_path($config['root_path'], $cache_path);
@@ -654,6 +717,7 @@ class cgsi_utils
 
 	  // and write the thing.
 	  if( is_object($img) ) {
+	    if( $opp['force_type'] ) $img['type'] = self::parse_type($opp['force_type']);
 	    if( $img['dirty'] ) $img->save($dest_fname,$opp['quality']);
 	  }
 	}
